abis = {
    b"\x00qP\xbe": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\x00\xdd\x87\xb9": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xf1a\xb2!": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x01\x8c\x84\xc2": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x03\x1cos": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"yC\xdcf": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x04T\xc0y": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x07\x82\x87\xf5": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"A\xb5\xef;": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x07\x83\x15\x02": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"L\xb6\x0f\xd1": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x08\x8e\xf9\xd2": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xc4\xd25\x07": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\t\x1f\xfa\xf5": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x01U\x0b\x04": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\n\xa6\xcf\xad": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x9bX\x8e\xcc": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x0b\xb0\x0e\xab": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"Fg\xde\x8e": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x0cf\xd1\xbe": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"R\x84\xbdl": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x0c\x9c\xd9\xc1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xca\x9a>\xb4": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\r&\xb9%": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x07\xc8\x12\x17": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\r6\xfa ": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\r\xf1+v": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x0e7\x89\x94": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x0e\xf7\xe0P": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"~%\r[": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x10\x0fe\x0e": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa5\xd9\x87h": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x10#\xf7\xb2": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"]OF\x80": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x10x\xf6\x8d": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x10\x93\xee\x11": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xc08*\xac": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x12\xd6\xc7\x88": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x12\xf2\x16\x02": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xb0\x13e\xbb": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x13k\x05\xdd": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"h\xf1X\xb5": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x157\xdc\x87": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xca\xa5#j": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x15\x96\xa1\xce": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'["\xb98': [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x15\x9f\x89'": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa1O\xd09": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x15\xc1'\xb5": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xfd\xb2\xec\xd4": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x15\xca\xc4v": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xa8\xe8 \xae": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x16\x06\xa3\x93": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8do\x9c\xa5": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x17b\xe3*": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x17\xfea\x85": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"l6mr": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x18\xc9\xc7F": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\x19?\xb8\x00": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\\\xa0\xad>": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x19\xfdIV": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x1a\xd9m\xe6": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"w\xa1\xab\xed": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x1b\xb3\xb0\x9a": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x18\t\x13A": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x1cA\xa36": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x1c~\xc4H": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xe3\x84\x9fy": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x1c\x9d~\xb3": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
    ],
    b"\x1em\xd4\xec": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
    ],
    b"\x1d\x14\xd0\x01": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x1d\xa9\x86\xea": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"]q\xf3\x9e": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x1d\xc8\xe1\xb8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa4\xc9*`": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x1eK\x87\xe5": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b" \t\x80\x14": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b'ZM\x99"': [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b" Xq\xc2": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b" q\x86P": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xd5\xce\xac\xe0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b" \xe3\x98M": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x1e\xf644": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'!"U\xcc': [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"!\xad\x06\x83": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"W\xdd\n\x11": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"!\xbd\xaf%": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b'"6\x03\xbd': [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'"\xf6\xb9\x99': [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"i\x8fC\x92": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"$Y\x86\xf2": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"$\x88\xb4\x14": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"UGE\xf9": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"$\xf9\x14e": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"4\xcb0\x8d": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"%U\xfaF": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"&\xf5`\xa8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x8a/\x90\xaa": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"'\xd8\xaf\xd2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"|\x03*2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"(\x86?\xcb": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8eJ\xe8n": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"*\x11\x0e\x83": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
    ],
    b"*\xe4\x08\xd4": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"++\x18\xdc": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b",\x17T\xed": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b",\x1d\x07F": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x91_\xdb(": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b",.\xcb\xc2": [{"internalType": "address", "name": "p0", "type": "address"}],
    b",\xd4\x13J": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b",\xed|\xef": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"-\x8e3\xa4": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"-\xd7x\xe6": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"1\x9a\xf33": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
    ],
    b"2E\x8e\xed": [{"internalType": "bool", "name": "p0", "type": "bool"}],
    b"3\xe9\xdd\x1d": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"4\xf0\xe66": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"=\x0e\x9d\xe4": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"5\x08_{": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"BN\xff\xbf": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"5L6\xd6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe3\x7f\xf3\xd0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"5\xa5\x07\x1f": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"7\x103g": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b";\\\x03\xe0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"7K\xb4\xb2": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"2\xdf\xa5$": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"7\xaa}L": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"[m\xe8?": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"8o\xf5\xf4": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc2\x10\xa0\x1e": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"9q\xe7\x8c": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x95\xd6_\x11": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"9\x91t\xd3": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"6Kj\x92": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b';"y\xb4': [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xab{\xd9\xfd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b";*\\\xe0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b";\xf5\xe57": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xfe\xa1\xd5Z": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b">\x12\x8c\xa3": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x8dw\x86$": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b">\x9f\x86j": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc5\xd1\xbb\x8b": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"?\x8ap\x1d": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"@xXi": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"A0O\xac": [{"internalType": "string", "name": "p0", "type": "string"}],
    b"B\xd2\x1d\xb7": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"C2\x85\xa2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"C\x9c{\xef": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"D\x880\xa8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"]\x13e\xc9": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"EMT\xa5": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x91\xfb\x12B": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"E\x7f\xe3\xcf": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8c\x193\xa9": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"F`\x0b\xe0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"F\x82k]": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa0\xc4\x14\xe8": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"G\\\\3": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"Gf\xdar": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"gW\x0f\xf7": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"G\x8d\x1cb": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xec$\x84o": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"H=\x04\x16": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"J(\xc0\x17": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x894\r\xab": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"Jf\xcb4": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"K\\Bw": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
    ],
    b"L\x12=W": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"`\x93\x86\xe7": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"L\xed\xa7Z": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"F\xa7\xd0\xce": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"O\x04\xfd\xc6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"XIz\xfe": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"Pp\x96\x98": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"P\xadF\x1d": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"Q^8\xb6": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xe7 R\x1c": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"Q\x97>\xc9": [],
    b"Q\xf0\x9f\xf8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa0hX3": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"S\x8e\x06\xab": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"T\xa7\xa9\xa0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x0b\xff\x95\r": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"V\xa5\xd1\xb1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xca\x93\x9b ": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"X!\xef\xa1": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xf3b\xcaY": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"Yp\xe0\x89": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xa3\xf5\xc79": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"Y\xcf\xcb\xe3": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"x\xadz\x0c": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"ZGv2": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"LU\xf24": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"Z\x9b^\xd5": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x88CC\xaa": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"Z\xb8N\x1f": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"l\x98\xda\xe2": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"Z\xbd\x99*": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"{\x08\xe8\xeb": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\\C\rG": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xdcy&\x04": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\\\x96\xb31": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xbe3I\x1b": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\\\xcdN7": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"]\x02\xc5\x0b": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"]\x08\xbb\x05": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"(\xdfN\x96": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"]\x1a\x97\x1a": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x8d\x14,\xdd": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"]\xa2\x97\xeb": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"8\x94\x16=": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"^\x84\xb0\xea": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"^\xa2\xb7\xae": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xea\xc8\x92\x81": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"_\x15\xd2\x8c": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"_\x1d\\\x9f": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"_t:|": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x19\xf6si": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"_{\x9a\xfb": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xebpK\xaf": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"ah\xeda": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x7f\xa5E\x8b": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"a\x9eM\x0e": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xab\\\xc1\xc4": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"c\x186x": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xdf\xd7\xd8\x0b": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"c\xcbA\xf9": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xce\x83\x04{": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"c\xfb\x8b\xc5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xa3f\xec\x80": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"d?\xd0\xdf": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
    ],
    b"\x0f\xa3\xf3E": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
    ],
    b"d\xb5\xbbg": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"]\xbf\xf08": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"f\x03u\xdd": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"f[\xf14": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"f\xf1\xbcg": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xecK\xa8\xa2": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"g\x82\t\xa8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xe5J\xe1D": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"g\xddo\xf1": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x1c\xda\xf2\x8a": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"h\xc8\xb8\xbd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa43\xfc\xfd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"i\x1a\x8ft": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x87Zn.": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"i'l\x86": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
    ],
    b"X\xeb\x86\x0c": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
    ],
    b"id\x0bY": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'S\x06"]': [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"j\x11\x99\xe2": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"A\x80\x01\x1b": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"j\x9cG\x8b": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"k\x0e]S": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b" \xbb\xc9\xaf": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"l\xde@\xb8": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xd6\xa2\xd1\xde": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"m\x1e\x87Q": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"mW/D": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"mpE\xc1": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc2H\x83M": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"m\xd44\xca": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"o\x1aYN": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"o|`>": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"q\x90\xa5)": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"q\xd0J\xf2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"}i\x0e\xe6": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"sn\xfb\xb6": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x9a<\xbf\x96": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"t-n\xe7": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"B\xb9\xa2'": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"td\xce#": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xbd%\xadY": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"u\x9f\x86\xbb": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
    ],
    b"u\xb6\x05\xd3": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
    ],
    b"v&\xdb\x92": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xf7<~=": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"y\x88L+": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"z\xf6\xab%": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xb2.\xaf\x06": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"z\xfa\xc9Y": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x1f\x90\xf2J": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"{\xc0\xd8H": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x97\xec\xa3\x94": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"{\xe0\xc3\xeb": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"]\xdb%\x92": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"{\xf1\x81\xa1": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x9b\xfer\xbc": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"|F2\xa4": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xbbr5\xe9": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"|\xc3\xc6\x07": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"J\x81\xa5j": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"}$I\x1d": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe9\x9f\x82\xcf": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"}\xd4\xd0\xe0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"Pa\x897": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x7f\x9b\xbc\xa2": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xd3\xdeU\x93": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x80\n\x1cg": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x80\xe6\xa2\x0b": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x9e\x12{n": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x82\x11*B": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x11\x06\xa8\xf7": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x82\xc2[t": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc0\x048\x07": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x83\t\xe8\xa8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b'"C\xcf\xa3': [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"\x85\x0bz\xd6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\x85<HI": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
    ],
    b"\x85K4\x96": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa5N\xd4\xbd": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x85wP!": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\x8b\x0e\x14\xfe": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\x88\xa8\xc4\x06": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"~V\xc6\x93": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x88\xcb`A": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"O@\x05\x8e": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x88\xf6\xe4\xb2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"a\x0b\xa8\xc0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x89Z\xf8\xc5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x8a\xf7\xcf\x8a": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"<\xc5\xb5\xd3": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x8c2\x9b\x1a": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x8cN]\xe6": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xcf\xb5\x87V": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8d\xa6\xde\xf5": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xd6\xc6Rv": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x8e?x\xa9": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x80u1\xe8": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8ei\xfb]": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xda\x06f\xc8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x8e\xaf\xb0+": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x9f\xd0\t\xf5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8e\xf3\xf3\x99": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"n\xb7\x94=": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8fsm\x16": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x8f\xea\xc5%": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
    ],
    b"\x90\xc3\nV": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xf9?\xff7": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x90\xfb\x06\xaa": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"c\xf0\xe2B": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x91C\xdb\xb1": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xb6\xd5i\xd4": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x91\xa0.*": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xd2\xab\xc4\xfd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x91\xd1\x11.": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x8fbK\xe9": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x93+\xbb8": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x93^\t\xbf": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"q\xd3\x85\r": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x94%\rw": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xed^\xac\x87": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x95\x8c(\xc6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x95\x91\xb9S": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x95\xed\x01\x95": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\x97\xd3\x94\xd8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x9a\x81j\x83": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe1\x17tO": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x9a\xcd6\x16": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"Bg\xc7\xf8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x9bBT\xe2": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xc2\xf6\x88\xec": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x9bn\xc0B": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"z\xd0\x12\x8e": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\x9c:\xdf\xa1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xf8\x98W\x7f": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x9cO\x99\xfb": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b",F\x8d\x15": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x9c\xba\x8f\xff": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xcb\xe5\x8e\xfd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'\x9d"\xd5\xdd': [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x9f\x1b\xc3n": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x9f\xfb/\x93": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"2T\xc2\xe8": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa0N/\x87": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xa0\xa4yc": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa1\xbc\xc9\xb3": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xf1\x81\xa1\xe9": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xa1\xefL\xbb": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\x86\xed\xc1\x0c": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xa1\xf2\xe8\xaa": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xba\xf9hI": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xa3\x1b\xfd\xcc": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"#\xe5Ir": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xa5\xb4\xfc\x99": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xef\xd9\xcb\xee": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa5\xca\xda\x94": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x1b\x0b\x95[": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa6\xf5\x0b\x0f": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xa7<\x1d\xb6": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa7\\Y\xde": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xdcq\x16\xd2": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa7\xa8xS": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x08\xeeVf": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa8&\xca\xeb": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xaae@\xc8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xaa\xbc\x9a1": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xab\x08Z\xe6": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x94\xbe;\xb1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xab\xf7:\x98": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"v\xcc`d": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xad\xe0R\xc7": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa20v\x1e": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xae.\xc5\x81": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"yo(\xa0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xb0(\xc9\xbd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"v\xecc^": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xb0v\x84\x7f": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xb0\xe0\xf9\xb5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xb1\x15a\x1f": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"?W\xc2\x95": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xb3\xa6\xb6\xbd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x12\x86+\x98": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xb4\xc3\x14\xff": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"e\xad\xf4\x08": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xb5\x9d\xbd`": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xb6\x0er\xcc": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"\x97\x10\xa9\xd0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"\xb6\x9b\xca\xf6": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x87\x86\x13^": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xb6\xf5w\xa1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"NlS\x15": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xb7\xb9\x14\xca": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xa2\xbc\x0c\x99": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xb8W\x16:": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xbaS]\x9c": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"Q\xbc+\xc1": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xbc\x0ba\xfe": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xbc\xfd\x9b\xe0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"}w\xa6\x1b": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xbeU4\x81": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"T\xfd\xf3\xe4": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xbe\x98CS": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xa4\x1d\x81\xde": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xbf\x01\xf8\x91": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xf5\x12\xcf\x9b": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc0\xa3\x02\xd8": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xc2\x1fd\xc7": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b'\x0b\x99\xfc"': [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc3q\xc7\xdb": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xc3\xa8\xa6T": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe6VX\xca": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xc3\xb5V5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
    ],
    b"\xc3\xfc9p": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xc89~\xb0": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xc4d> ": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x85\xcd\xc5\xaf": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xc5\x98\xd1\x85": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"dR\xb9\xcb": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xc5\xad\x85\xf9": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x8e\x8eNu": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xc6~\xa9\xd1": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa0\xc4\xb2%": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc6\xac\xc7\xa8": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"V\x82\x8d\xa4": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xc9\x1d^\xd4": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xc9YX\xd6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b")\x1b\xb9\xd0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xcaG\xc4\xeb": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\x96\x9c\xdd\x03": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xcaw3\xb1": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xf1\x02\xee\x05": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xca\xc44y": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xcc2\xab\x07": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b'"\xa4y\xa6': [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xcc\xf7\x90\xa1": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\r\x8c\xe6\x1e": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xce\xb5\xf4\xd7": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x9e\x01\xf7A": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xcf\x00\x98\x80": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xa4\xb4\x8a\x7f": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xcf\x02\x0f\xb1": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xcf\x18\x10\\": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xa4\x02O\x11": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xcf9D\x85": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xd1\xedz<": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xe7\x82\nt": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
    ],
    b"\xd2v6g": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xd2\xd4#\xcd": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x8dH\x9c\xa0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xd5\x83\xc6\x02": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xcc\x98\x8a\xa0": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xd6\x01\x9f\x1c": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xee\x8d\x86r": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xd6\xae\xfa\xd2": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x86\x81\x8az": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xd8\x12\xa1g": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xda\xf0\xd4\xaa": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
    ],
    b"\xdb\xb4\xc2G": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xdc^\x93[": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xdd\xb0e!": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b">\xd3\xbd(": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xdd\xdb\x95a": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"1\x8a\xe5\x9b": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xde\x03\xe7t": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xe8\xdd\xbcV": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xdeh\xf2\n": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xde\x9a\x92p": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xdf\xc4\xa2\xe8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xe0b[)": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe0\xe9[\x98": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe5T\x9d\x91": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe0\xe9\xadO": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xe2\x1d\xe2x": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xbe\xd7(\xbf": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe2\x98\xf4}": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xe2\xbf\xd6\x0b": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe3Q\x14\x0f": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"~'A\r": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe3\xa9\xca/": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x17\x8bF\x85": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xe4\x1boo": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"U\x0en\xf5": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xe5\xe7\x0b+": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\x91\xd2\xf8\x13": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xe8\xd3\x01\x8d": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x98\xe7\xf3\xf3": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xe8\xde\xfb\xa9": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\x1b\xad\xc9\xeb": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xeb\x1b\xff\x80": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xeb\x7fo\xd2": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"ld|\x8c": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xeb\x83\x0c\x92": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xeb\x92\x8d\x7f": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"4n\xb8\xc7": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xed\x8f(\xf6": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xef\x1c\xef\xe7": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\x04(\x93\x00": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xefR\x90\x18": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"In+\xb4": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xefr\xc5\x13": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xb610\x94": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xf0\x87D\xe8": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xf1\x16\x99\xed": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xf2\xa6b\x86": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "bool", "name": "p2", "type": "bool"},
    ],
    b"\xf4]},": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xd5\xcf\x17\xd0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xf4\x88\x0e\xa4": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'\xf5\xbc"I': [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xd3*eH": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xf6fqZ": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"l\x0fi\x80": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
    ],
    b"\xf7\xe3bE": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xf8\x08\xda ": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xf8,P\xf1": [{"internalType": "uint256", "name": "p0", "type": "uint256"}],
    b"\xf5\xb1\xbb\xa9": [{"internalType": "uint256", "name": "p0", "type": "uint256"}],
    b"\xf8\xf5\x1b\x1e": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xda\xa3\x94\xbd": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "uint256", "name": "p3", "type": "uint256"},
    ],
    b"\xf9\xad+\x89": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "bool", "name": "p1", "type": "bool"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xfa\x81\x85\xaf": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xe0\x85?i": [
        {"internalType": "uint256", "name": "p0", "type": "uint256"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b'\xfbw"e': [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "string", "name": "p1", "type": "string"},
        {"internalType": "string", "name": "p2", "type": "string"},
    ],
    b"\xfcHE\xf0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"Z\xc1\xc1<": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "bool", "name": "p3", "type": "bool"},
    ],
    b"\xfc\xecu\xe0": [
        {"internalType": "string", "name": "p0", "type": "string"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "address", "name": "p2", "type": "address"},
    ],
    b"\xfd\xb4\xf9\x90": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\x9d\xd1.\xad": [
        {"internalType": "address", "name": "p0", "type": "address"},
        {"internalType": "address", "name": "p1", "type": "address"},
        {"internalType": "uint256", "name": "p2", "type": "uint256"},
        {"internalType": "string", "name": "p3", "type": "string"},
    ],
    b"\xfe\xdd\x1f\xff": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"\xa5\xc7\r)": [
        {"internalType": "bool", "name": "p0", "type": "bool"},
        {"internalType": "uint256", "name": "p1", "type": "uint256"},
        {"internalType": "string", "name": "p2", "type": "string"},
        {"internalType": "address", "name": "p3", "type": "address"},
    ],
    b"-[l\xb9": [{"internalType": "int256", "name": "p0", "type": "int256"}],
    b"N\x0c\x1d\x1d": [{"internalType": "int256", "name": "p0", "type": "int256"}],
    b"\x0b\xe7\x7fV": [{"internalType": "bytes", "name": "p0", "type": "bytes"}],
    b"n\x18\xa1(": [{"internalType": "bytes1", "name": "p0", "type": "bytes1"}],
    b'\xe9\xb6"\x96': [{"internalType": "bytes2", "name": "p0", "type": "bytes2"}],
    b"-\x83I&": [{"internalType": "bytes3", "name": "p0", "type": "bytes3"}],
    b"\xe0_H\xd1": [{"internalType": "bytes4", "name": "p0", "type": "bytes4"}],
    b"\xa6\x84\x80\x8d": [{"internalType": "bytes5", "name": "p0", "type": "bytes5"}],
    b"\xae\x84\xa5\x91": [{"internalType": "bytes6", "name": "p0", "type": "bytes6"}],
    b"N\xd5~(": [{"internalType": "bytes7", "name": "p0", "type": "bytes7"}],
    b"O\x84%.": [{"internalType": "bytes8", "name": "p0", "type": "bytes8"}],
    b"\x90\xbd\x8c\xd0": [{"internalType": "bytes9", "name": "p0", "type": "bytes9"}],
    b"\x01=\x17\x8b": [{"internalType": "bytes10", "name": "p0", "type": "bytes10"}],
    b"\x04\x00J.": [{"internalType": "bytes11", "name": "p0", "type": "bytes11"}],
    b"\x86\xa0j\xbd": [{"internalType": "bytes12", "name": "p0", "type": "bytes12"}],
    b"\x94R\x9e4": [{"internalType": "bytes13", "name": "p0", "type": "bytes13"}],
    b"\x92f\xf0\x7f": [{"internalType": "bytes14", "name": "p0", "type": "bytes14"}],
    b"\xda\x95t\xe0": [{"internalType": "bytes15", "name": "p0", "type": "bytes15"}],
    b"f\\a\x04": [{"internalType": "bytes16", "name": "p0", "type": "bytes16"}],
    b"3\x9fg:": [{"internalType": "bytes17", "name": "p0", "type": "bytes17"}],
    b"\xc4\xd2=\x9a": [{"internalType": "bytes18", "name": "p0", "type": "bytes18"}],
    b"^kZ3": [{"internalType": "bytes19", "name": "p0", "type": "bytes19"}],
    b"Q\x88\xe3\xe9": [{"internalType": "bytes20", "name": "p0", "type": "bytes20"}],
    b"\xe9\xda5`": [{"internalType": "bytes21", "name": "p0", "type": "bytes21"}],
    b"\xd5\xfa\xe8\x9c": [{"internalType": "bytes22", "name": "p0", "type": "bytes22"}],
    b"\xab\xa1\xcf\r": [{"internalType": "bytes23", "name": "p0", "type": "bytes23"}],
    b"\xf1\xb3[4": [{"internalType": "bytes24", "name": "p0", "type": "bytes24"}],
    b"\x0b\x84\xbcX": [{"internalType": "bytes25", "name": "p0", "type": "bytes25"}],
    b"\xf8\xb1I\xf1": [{"internalType": "bytes26", "name": "p0", "type": "bytes26"}],
    b":7W\xdd": [{"internalType": "bytes27", "name": "p0", "type": "bytes27"}],
    b"\xc8*\xea\xee": [{"internalType": "bytes28", "name": "p0", "type": "bytes28"}],
    b"Ki\xc3\xd5": [{"internalType": "bytes29", "name": "p0", "type": "bytes29"}],
    b"\xee\x12\xc4\xed": [{"internalType": "bytes30", "name": "p0", "type": "bytes30"}],
    b"\xc2\x85M\x92": [{"internalType": "bytes31", "name": "p0", "type": "bytes31"}],
    b"'\xb7\xcf\x85": [{"internalType": "bytes32", "name": "p0", "type": "bytes32"}],
}
